:four_leaf_clover: clover_wallpaper
==================
[![Build Status](https://travis-ci.com/collinarnett/clover_wallpaper.svg?branch=master)](https://travis-ci.com/collinarnett/clover_wallpaper)

cloverwallpaper makes it simple to fetch all images on a 4chan board for a specified resolution, making it ideal for finding wallpapers.

Installation
---------------

### Dependencies

cloverwallpaper requires:
 
 - python (>= 3.6)
 - tqdm
 - requests

### User installation

```
pip install cloverwallpaper
```

Usage
---------

```
usage: cloverwallpaper [-h] --board BOARD --height HEIGHT --width WIDTH

optional arguments:
  -h, --help       show this help message and exit
  --board BOARD    target board to scrape images from
  --height HEIGHT  height of the images you wish to download
  --width WIDTH    width of the images you wish to download
```
